import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import '../css/global.css';
import PlayVideo from './components/playVideo.jsx';
import LoadImage from './components/loadImage.jsx';
import LoadingScene from './components/loadingScene.jsx';
import IntroductionData from './components/introductionData.jsx';
import SelectionCharacter from './components/selectionCharacter.jsx';
import Character from './class/character.jsx';

function IntroductionPage() {
    const navigate = useNavigate();
    const [loading, setLoading] = useState(false);
    const [isClickedIntroduction, setIsClickedIntroduction] = useState(false);
    const [numChar, setNumChar] = useState(1);
    const character = new Character();

    const handleLeftClicked = () => {
        setNumChar(prev => (prev - 1 < 1 ? 3 : prev - 1));
    };

    const handleRightClicked = () => {
        setNumChar(prev => (prev + 1 > 3 ? 1 : prev + 1));
    };

    const handleClickIntroduction = () => {
        setIsClickedIntroduction(true);
    };

    const handleVideoReady = () => {
        setLoading(false);
    };
    
    const [lang] = useState(() => {
        return sessionStorage.getItem("lang") || 'English';
    });

    const userAgent = navigator.userAgent;
    const isSafari = userAgent.includes("iPhone"); // safari piss me off so bad omg

    const videoElement = isSafari ? (
        <LoadImage
            src='bg-hallway.png'
            side={character.position(numChar)}
            onVideoReady={handleVideoReady}
        />
    ) : (
        <PlayVideo
            src='hallway_FFF.mp4'
            side={character.position(numChar)}
            onVideoReady={handleVideoReady}
        />
    );

    const handleClickedButton = () => {
        console.log(character.name(numChar))
        if(character.name(numChar)=='Porsche') navigate(`/vs/Porsche/${lang}/0`);
        if(character.name(numChar)=='Pie') navigate(`/vs/Pie/${lang}/0`);
        if(character.name(numChar)=='Patt') navigate(`/vs/Pat/${lang}/0`);
    }

    return (
        <div style={{ width: "100vw", height: "100vh" }}>
            {loading ? (
                <LoadingScene />
            ) : (
                !isClickedIntroduction ? (
                    <IntroductionData onClickedIntroduction={handleClickIntroduction} />
                ) : (
                    <SelectionCharacter
                        onClickedLeft={handleLeftClicked}
                        onClickedRight={handleRightClicked}
                        nameChar={character.name(numChar)}
                        onClickedButton={handleClickedButton}
                    />
                )
            )}
            {videoElement}
        </div>
    );
}

export default IntroductionPage;
